Diofant
=======

|Build status| |Coverage status| |docs|

.. |Build status| image:: https://secure.travis-ci.org/diofant/diofant.svg?branch=master
   :target: https://travis-ci.org/diofant/diofant

.. |Coverage status| image:: https://codecov.io/gh/diofant/diofant/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/diofant/diofant

.. |docs| image:: https://readthedocs.org/projects/diofant/badge/?style=flat
    :target: https://diofant.readthedocs.io/en/latest/

A Python library for symbolic mathematics.

For `installation instructions`_ and usage information,
see the `online documentation`_.

`New BSD License`_ covers all files in this repository unless stated otherwise.

.. _online documentation: https://diofant.readthedocs.io/en/latest/
.. _installation instructions: https://diofant.readthedocs.io/en/latest/install.html#installation
.. _New BSD License: https://github.com/diofant/diofant/blob/master/LICENSE.rst
